Class: Google::Apis::DoubleclicksearchV2::Report

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/doubleclicksearch_v2/classes.rb,
lib/google/apis/doubleclicksearch_v2/representations.rb,
lib/google/apis/doubleclicksearch_v2/representations.rb

Overview

A DoubleClick Search report. This object contains the report request, some report metadata such as currency code, and the generated report rows or report files.

Defined Under Namespace

Classes: File

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Report

Returns a new instance of Report.



482
483
484
# File 'lib/google/apis/doubleclicksearch_v2/classes.rb', line 482

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#filesArray<Google::Apis::DoubleclicksearchV2::Report::File>

Asynchronous report only. Contains a list of generated report files once the report has successfully completed. Corresponds to the JSON property files



433
434
435
# File 'lib/google/apis/doubleclicksearch_v2/classes.rb', line 433

def files
  @files
end

#idString

Asynchronous report only. Id of the report. Corresponds to the JSON property id

Returns:

  • (String)


438
439
440
# File 'lib/google/apis/doubleclicksearch_v2/classes.rb', line 438

def id
  @id
end

#is_report_readyBoolean Also known as: is_report_ready?

Asynchronous report only. True if and only if the report has completed successfully and the report files are ready to be downloaded. Corresponds to the JSON property isReportReady

Returns:

  • (Boolean)


444
445
446
# File 'lib/google/apis/doubleclicksearch_v2/classes.rb', line 444

def is_report_ready
  @is_report_ready
end

#kindString

Identifies this as a Report resource. Value: the fixed string doubleclicksearch#report. Corresponds to the JSON property kind

Returns:

  • (String)


451
452
453
# File 'lib/google/apis/doubleclicksearch_v2/classes.rb', line 451

def kind
  @kind
end

#requestGoogle::Apis::DoubleclicksearchV2::ReportRequest

A request object used to create a DoubleClick Search report. Corresponds to the JSON property request



456
457
458
# File 'lib/google/apis/doubleclicksearch_v2/classes.rb', line 456

def request
  @request
end

#row_countFixnum

The number of report rows generated by the report, not including headers. Corresponds to the JSON property rowCount

Returns:

  • (Fixnum)


461
462
463
# File 'lib/google/apis/doubleclicksearch_v2/classes.rb', line 461

def row_count
  @row_count
end

#rowsArray<Hash<String,Object>>

Synchronous report only. Generated report rows. Corresponds to the JSON property rows

Returns:

  • (Array<Hash<String,Object>>)


466
467
468
# File 'lib/google/apis/doubleclicksearch_v2/classes.rb', line 466

def rows
  @rows
end

#statistics_currency_codeString

The currency code of all monetary values produced in the report, including values that are set by users (e.g., keyword bid settings) and metrics (e.g., cost and revenue). The currency code of a report is determined by the statisticsCurrency field of the report request. Corresponds to the JSON property statisticsCurrencyCode

Returns:

  • (String)


474
475
476
# File 'lib/google/apis/doubleclicksearch_v2/classes.rb', line 474

def statistics_currency_code
  @statistics_currency_code
end

#statistics_time_zoneString

If all statistics of the report are sourced from the same time zone, this would be it. Otherwise the field is unset. Corresponds to the JSON property statisticsTimeZone

Returns:

  • (String)


480
481
482
# File 'lib/google/apis/doubleclicksearch_v2/classes.rb', line 480

def statistics_time_zone
  @statistics_time_zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



487
488
489
490
491
492
493
494
495
496
497
# File 'lib/google/apis/doubleclicksearch_v2/classes.rb', line 487

def update!(**args)
  @files = args[:files] if args.key?(:files)
  @id = args[:id] if args.key?(:id)
  @is_report_ready = args[:is_report_ready] if args.key?(:is_report_ready)
  @kind = args[:kind] if args.key?(:kind)
  @request = args[:request] if args.key?(:request)
  @row_count = args[:row_count] if args.key?(:row_count)
  @rows = args[:rows] if args.key?(:rows)
  @statistics_currency_code = args[:statistics_currency_code] if args.key?(:statistics_currency_code)
  @statistics_time_zone = args[:statistics_time_zone] if args.key?(:statistics_time_zone)
end