Class: Google::Apis::DoubleclicksearchV2::ReportApiColumnSpec
- Inherits:
-
Object
- Object
- Google::Apis::DoubleclicksearchV2::ReportApiColumnSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/doubleclicksearch_v2/classes.rb,
lib/google/apis/doubleclicksearch_v2/representations.rb,
lib/google/apis/doubleclicksearch_v2/representations.rb
Overview
A request object used to create a DoubleClick Search report.
Instance Attribute Summary collapse
-
#column_name ⇒ String
Name of a DoubleClick Search column to include in the report.
-
#custom_dimension_name ⇒ String
Segments a report by a custom dimension.
-
#custom_metric_name ⇒ String
Name of a custom metric to include in the report.
-
#end_date ⇒ String
Inclusive day in YYYY-MM-DD format.
-
#group_by_column ⇒ Boolean
(also: #group_by_column?)
Synchronous report only.
-
#header_text ⇒ String
Text used to identify this column in the report output; defaults to
columnNameorsavedColumnNamewhen not specified. -
#platform_source ⇒ String
The platform that is used to provide data for the custom dimension.
-
#product_report_perspective ⇒ String
Returns metrics only for a specific type of product activity.
-
#saved_column_name ⇒ String
Name of a saved column to include in the report.
-
#start_date ⇒ String
Inclusive date in YYYY-MM-DD format.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReportApiColumnSpec
constructor
A new instance of ReportApiColumnSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReportApiColumnSpec
Returns a new instance of ReportApiColumnSpec.
602 603 604 |
# File 'lib/google/apis/doubleclicksearch_v2/classes.rb', line 602 def initialize(**args) update!(**args) end |
Instance Attribute Details
#column_name ⇒ String
Name of a DoubleClick Search column to include in the report.
Corresponds to the JSON property columnName
532 533 534 |
# File 'lib/google/apis/doubleclicksearch_v2/classes.rb', line 532 def column_name @column_name end |
#custom_dimension_name ⇒ String
Segments a report by a custom dimension. The report must be scoped to an
advertiser or lower, and the custom dimension must already be set up in
DoubleClick Search. The custom dimension name, which appears in DoubleClick
Search, is case sensitive.\ If used in a conversion report, returns the value
of the specified custom dimension for the given conversion, if set. This
column does not segment the conversion report.
Corresponds to the JSON property customDimensionName
542 543 544 |
# File 'lib/google/apis/doubleclicksearch_v2/classes.rb', line 542 def custom_dimension_name @custom_dimension_name end |
#custom_metric_name ⇒ String
Name of a custom metric to include in the report. The report must be scoped to
an advertiser or lower, and the custom metric must already be set up in
DoubleClick Search. The custom metric name, which appears in DoubleClick
Search, is case sensitive.
Corresponds to the JSON property customMetricName
550 551 552 |
# File 'lib/google/apis/doubleclicksearch_v2/classes.rb', line 550 def custom_metric_name @custom_metric_name end |
#end_date ⇒ String
Inclusive day in YYYY-MM-DD format. When provided, this overrides the overall
time range of the report for this column only. Must be provided together with
startDate.
Corresponds to the JSON property endDate
557 558 559 |
# File 'lib/google/apis/doubleclicksearch_v2/classes.rb', line 557 def end_date @end_date end |
#group_by_column ⇒ Boolean Also known as: group_by_column?
Synchronous report only. Set to true to group by this column. Defaults to
false.
Corresponds to the JSON property groupByColumn
563 564 565 |
# File 'lib/google/apis/doubleclicksearch_v2/classes.rb', line 563 def group_by_column @group_by_column end |
#header_text ⇒ String
Text used to identify this column in the report output; defaults to
columnName or savedColumnName when not specified. This can be used to
prevent collisions between DoubleClick Search columns and saved columns with
the same name.
Corresponds to the JSON property headerText
572 573 574 |
# File 'lib/google/apis/doubleclicksearch_v2/classes.rb', line 572 def header_text @header_text end |
#platform_source ⇒ String
The platform that is used to provide data for the custom dimension. Acceptable
values are "floodlight".
Corresponds to the JSON property platformSource
578 579 580 |
# File 'lib/google/apis/doubleclicksearch_v2/classes.rb', line 578 def platform_source @platform_source end |
#product_report_perspective ⇒ String
Returns metrics only for a specific type of product activity. Accepted values
are: - "sold": returns metrics only for products that were sold - "
advertised": returns metrics only for products that were advertised in a
Shopping campaign, and that might or might not have been sold
Corresponds to the JSON property productReportPerspective
586 587 588 |
# File 'lib/google/apis/doubleclicksearch_v2/classes.rb', line 586 def product_report_perspective @product_report_perspective end |
#saved_column_name ⇒ String
Name of a saved column to include in the report. The report must be scoped at
advertiser or lower, and this saved column must already be created in the
DoubleClick Search UI.
Corresponds to the JSON property savedColumnName
593 594 595 |
# File 'lib/google/apis/doubleclicksearch_v2/classes.rb', line 593 def saved_column_name @saved_column_name end |
#start_date ⇒ String
Inclusive date in YYYY-MM-DD format. When provided, this overrides the overall
time range of the report for this column only. Must be provided together with
endDate.
Corresponds to the JSON property startDate
600 601 602 |
# File 'lib/google/apis/doubleclicksearch_v2/classes.rb', line 600 def start_date @start_date end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
607 608 609 610 611 612 613 614 615 616 617 618 |
# File 'lib/google/apis/doubleclicksearch_v2/classes.rb', line 607 def update!(**args) @column_name = args[:column_name] if args.key?(:column_name) @custom_dimension_name = args[:custom_dimension_name] if args.key?(:custom_dimension_name) @custom_metric_name = args[:custom_metric_name] if args.key?(:custom_metric_name) @end_date = args[:end_date] if args.key?(:end_date) @group_by_column = args[:group_by_column] if args.key?(:group_by_column) @header_text = args[:header_text] if args.key?(:header_text) @platform_source = args[:platform_source] if args.key?(:platform_source) @product_report_perspective = args[:product_report_perspective] if args.key?(:product_report_perspective) @saved_column_name = args[:saved_column_name] if args.key?(:saved_column_name) @start_date = args[:start_date] if args.key?(:start_date) end |