Class: Google::Apis::DoubleclicksearchV2::ReportRequest
- Inherits:
-
Object
- Object
- Google::Apis::DoubleclicksearchV2::ReportRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/doubleclicksearch_v2/classes.rb,
lib/google/apis/doubleclicksearch_v2/representations.rb,
lib/google/apis/doubleclicksearch_v2/representations.rb
Overview
A request object used to create a DoubleClick Search report.
Defined Under Namespace
Classes: Filter, OrderBy, ReportScope, TimeRange
Instance Attribute Summary collapse
-
#columns ⇒ Array<Google::Apis::DoubleclicksearchV2::ReportApiColumnSpec>
The columns to include in the report.
-
#download_format ⇒ String
Format that the report should be returned in.
-
#filters ⇒ Array<Google::Apis::DoubleclicksearchV2::ReportRequest::Filter>
A list of filters to be applied to the report.\ The maximum number of filters per request is 300.
-
#include_deleted_entities ⇒ Boolean
(also: #include_deleted_entities?)
Determines if removed entities should be included in the report.
-
#include_removed_entities ⇒ Boolean
(also: #include_removed_entities?)
Determines if removed entities should be included in the report.
-
#max_rows_per_file ⇒ Fixnum
Asynchronous report only.
-
#order_by ⇒ Array<Google::Apis::DoubleclicksearchV2::ReportRequest::OrderBy>
Synchronous report only.
-
#report_scope ⇒ Google::Apis::DoubleclicksearchV2::ReportRequest::ReportScope
The reportScope is a set of IDs that are used to determine which subset of entities will be returned in the report.
-
#report_type ⇒ String
Determines the type of rows that are returned in the report.
-
#row_count ⇒ Fixnum
Synchronous report only.
-
#start_row ⇒ Fixnum
Synchronous report only.
-
#statistics_currency ⇒ String
Specifies the currency in which monetary will be returned.
-
#time_range ⇒ Google::Apis::DoubleclicksearchV2::ReportRequest::TimeRange
If metrics are requested in a report, this argument will be used to restrict the metrics to a specific time range.
-
#verify_single_time_zone ⇒ Boolean
(also: #verify_single_time_zone?)
If
true, the report would only be created if all the requested stat data are sourced from a single timezone.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReportRequest
constructor
A new instance of ReportRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReportRequest
Returns a new instance of ReportRequest.
723 724 725 |
# File 'lib/google/apis/doubleclicksearch_v2/classes.rb', line 723 def initialize(**args) update!(**args) end |
Instance Attribute Details
#columns ⇒ Array<Google::Apis::DoubleclicksearchV2::ReportApiColumnSpec>
The columns to include in the report. This includes both DoubleClick Search
columns and saved columns. For DoubleClick Search columns, only the
columnName parameter is required. For saved columns only the savedColumnName
parameter is required. Both columnName and savedColumnName cannot be set
in the same stanza.\ The maximum number of columns per request is 300.
Corresponds to the JSON property columns
632 633 634 |
# File 'lib/google/apis/doubleclicksearch_v2/classes.rb', line 632 def columns @columns end |
#download_format ⇒ String
Format that the report should be returned in. Currently csv or tsv is
supported.
Corresponds to the JSON property downloadFormat
638 639 640 |
# File 'lib/google/apis/doubleclicksearch_v2/classes.rb', line 638 def download_format @download_format end |
#filters ⇒ Array<Google::Apis::DoubleclicksearchV2::ReportRequest::Filter>
A list of filters to be applied to the report.\ The maximum number of filters
per request is 300.
Corresponds to the JSON property filters
644 645 646 |
# File 'lib/google/apis/doubleclicksearch_v2/classes.rb', line 644 def filters @filters end |
#include_deleted_entities ⇒ Boolean Also known as: include_deleted_entities?
Determines if removed entities should be included in the report. Defaults to
false. Deprecated, please use includeRemovedEntities instead.
Corresponds to the JSON property includeDeletedEntities
650 651 652 |
# File 'lib/google/apis/doubleclicksearch_v2/classes.rb', line 650 def include_deleted_entities @include_deleted_entities end |
#include_removed_entities ⇒ Boolean Also known as: include_removed_entities?
Determines if removed entities should be included in the report. Defaults to
false.
Corresponds to the JSON property includeRemovedEntities
657 658 659 |
# File 'lib/google/apis/doubleclicksearch_v2/classes.rb', line 657 def include_removed_entities @include_removed_entities end |
#max_rows_per_file ⇒ Fixnum
Asynchronous report only. The maximum number of rows per report file. A large
report is split into many files based on this field. Acceptable values are
1000000 to 100000000, inclusive.
Corresponds to the JSON property maxRowsPerFile
665 666 667 |
# File 'lib/google/apis/doubleclicksearch_v2/classes.rb', line 665 def max_rows_per_file @max_rows_per_file end |
#order_by ⇒ Array<Google::Apis::DoubleclicksearchV2::ReportRequest::OrderBy>
Synchronous report only. A list of columns and directions defining sorting to
be performed on the report rows.\ The maximum number of orderings per request
is 300.
Corresponds to the JSON property orderBy
672 673 674 |
# File 'lib/google/apis/doubleclicksearch_v2/classes.rb', line 672 def order_by @order_by end |
#report_scope ⇒ Google::Apis::DoubleclicksearchV2::ReportRequest::ReportScope
The reportScope is a set of IDs that are used to determine which subset of
entities will be returned in the report. The full lineage of IDs from the
lowest scoped level desired up through agency is required.
Corresponds to the JSON property reportScope
679 680 681 |
# File 'lib/google/apis/doubleclicksearch_v2/classes.rb', line 679 def report_scope @report_scope end |
#report_type ⇒ String
Determines the type of rows that are returned in the report. For example, if
you specify reportType: keyword, each row in the report will contain data
about a keyword. See the Types of Reports
reference for the columns that are available for each type.
Corresponds to the JSON property reportType
687 688 689 |
# File 'lib/google/apis/doubleclicksearch_v2/classes.rb', line 687 def report_type @report_type end |
#row_count ⇒ Fixnum
Synchronous report only. The maximum number of rows to return; additional rows
are dropped. Acceptable values are 0 to 10000, inclusive. Defaults to
10000.
Corresponds to the JSON property rowCount
694 695 696 |
# File 'lib/google/apis/doubleclicksearch_v2/classes.rb', line 694 def row_count @row_count end |
#start_row ⇒ Fixnum
Synchronous report only. Zero-based index of the first row to return.
Acceptable values are 0 to 50000, inclusive. Defaults to 0.
Corresponds to the JSON property startRow
700 701 702 |
# File 'lib/google/apis/doubleclicksearch_v2/classes.rb', line 700 def start_row @start_row end |
#statistics_currency ⇒ String
Specifies the currency in which monetary will be returned. Possible values are:
usd, agency (valid if the report is scoped to agency or lower),
advertiser (valid if the report is scoped to * advertiser or lower), or
account (valid if the report is scoped to engine account or lower).
Corresponds to the JSON property statisticsCurrency
708 709 710 |
# File 'lib/google/apis/doubleclicksearch_v2/classes.rb', line 708 def statistics_currency @statistics_currency end |
#time_range ⇒ Google::Apis::DoubleclicksearchV2::ReportRequest::TimeRange
If metrics are requested in a report, this argument will be used to restrict
the metrics to a specific time range.
Corresponds to the JSON property timeRange
714 715 716 |
# File 'lib/google/apis/doubleclicksearch_v2/classes.rb', line 714 def time_range @time_range end |
#verify_single_time_zone ⇒ Boolean Also known as: verify_single_time_zone?
If true, the report would only be created if all the requested stat data are
sourced from a single timezone. Defaults to false.
Corresponds to the JSON property verifySingleTimeZone
720 721 722 |
# File 'lib/google/apis/doubleclicksearch_v2/classes.rb', line 720 def verify_single_time_zone @verify_single_time_zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
728 729 730 731 732 733 734 735 736 737 738 739 740 741 742 743 |
# File 'lib/google/apis/doubleclicksearch_v2/classes.rb', line 728 def update!(**args) @columns = args[:columns] if args.key?(:columns) @download_format = args[:download_format] if args.key?(:download_format) @filters = args[:filters] if args.key?(:filters) @include_deleted_entities = args[:include_deleted_entities] if args.key?(:include_deleted_entities) @include_removed_entities = args[:include_removed_entities] if args.key?(:include_removed_entities) @max_rows_per_file = args[:max_rows_per_file] if args.key?(:max_rows_per_file) @order_by = args[:order_by] if args.key?(:order_by) @report_scope = args[:report_scope] if args.key?(:report_scope) @report_type = args[:report_type] if args.key?(:report_type) @row_count = args[:row_count] if args.key?(:row_count) @start_row = args[:start_row] if args.key?(:start_row) @statistics_currency = args[:statistics_currency] if args.key?(:statistics_currency) @time_range = args[:time_range] if args.key?(:time_range) @verify_single_time_zone = args[:verify_single_time_zone] if args.key?(:verify_single_time_zone) end |