Class: Google::Apis::DoubleclicksearchV2::ReportRequest::Filter

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/doubleclicksearch_v2/classes.rb,
lib/google/apis/doubleclicksearch_v2/representations.rb,
lib/google/apis/doubleclicksearch_v2/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Filter

Returns a new instance of Filter.



766
767
768
# File 'lib/google/apis/doubleclicksearch_v2/classes.rb', line 766

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#columnGoogle::Apis::DoubleclicksearchV2::ReportApiColumnSpec

A request object used to create a DoubleClick Search report. Corresponds to the JSON property column



752
753
754
# File 'lib/google/apis/doubleclicksearch_v2/classes.rb', line 752

def column
  @column
end

#operatorString

Operator to use in the filter. See the filter reference for a list of available operators. Corresponds to the JSON property operator

Returns:

  • (String)


758
759
760
# File 'lib/google/apis/doubleclicksearch_v2/classes.rb', line 758

def operator
  @operator
end

#valuesArray<Object>

A list of values to filter the column value against.\ The maximum number of filter values per request is 300. Corresponds to the JSON property values

Returns:

  • (Array<Object>)


764
765
766
# File 'lib/google/apis/doubleclicksearch_v2/classes.rb', line 764

def values
  @values
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



771
772
773
774
775
# File 'lib/google/apis/doubleclicksearch_v2/classes.rb', line 771

def update!(**args)
  @column = args[:column] if args.key?(:column)
  @operator = args[:operator] if args.key?(:operator)
  @values = args[:values] if args.key?(:values)
end