Class: Google::Apis::DoubleclicksearchV2::Conversion
- Inherits:
-
Object
- Object
- Google::Apis::DoubleclicksearchV2::Conversion
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/doubleclicksearch_v2/classes.rb,
lib/google/apis/doubleclicksearch_v2/representations.rb,
lib/google/apis/doubleclicksearch_v2/representations.rb
Overview
A conversion containing data relevant to DoubleClick Search. Common DS3 API conversion fields: Id Range [1 - 2800]. Next Id to use: 33
Instance Attribute Summary collapse
-
#ad_group_id ⇒ Fixnum
DS ad group ID.
-
#ad_id ⇒ Fixnum
DS ad ID.
-
#ad_user_data_consent ⇒ String
Represents consent for core platform services (CPS) preferences in settings.
-
#advertiser_id ⇒ Fixnum
DS advertiser ID.
-
#agency_id ⇒ Fixnum
DS agency ID.
-
#attribution_model ⇒ String
Available to advertisers only after contacting DoubleClick Search customer support.
-
#campaign_id ⇒ Fixnum
DS campaign ID.
-
#channel ⇒ String
Sales channel for the product.
-
#click_id ⇒ String
DS click ID for the conversion.
-
#conversion_id ⇒ String
For offline conversions, advertisers provide this ID.
-
#conversion_modified_timestamp ⇒ Fixnum
The time at which the conversion was last modified, in epoch millis UTC.
-
#conversion_timestamp ⇒ String
The time at which the conversion took place, in epoch millis UTC.
-
#count_millis ⇒ Fixnum
Available to advertisers only after contacting DoubleClick Search customer support.
-
#criterion_id ⇒ Fixnum
DS criterion (keyword) ID.
-
#currency_code ⇒ String
The currency code for the conversion's revenue.
-
#custom_dimension ⇒ Array<Google::Apis::DoubleclicksearchV2::CustomDimension>
Custom dimensions for the conversion, which can be used to filter data in a report.
-
#custom_metric ⇒ Array<Google::Apis::DoubleclicksearchV2::CustomMetric>
Custom metrics for the conversion.
-
#customer_id ⇒ String
Customer ID of a client account in the new Search Ads 360 experience.
-
#device_type ⇒ String
The type of device on which the conversion occurred.
-
#ds_conversion_id ⇒ Fixnum
ID that DoubleClick Search generates for each conversion.
-
#engine_account_id ⇒ Fixnum
DS engine account ID.
-
#floodlight_order_id ⇒ String
The Floodlight order ID provided by the advertiser for the conversion.
-
#inventory_account_id ⇒ Fixnum
ID that DS generates and uses to uniquely identify the inventory account that contains the product.
-
#product_country ⇒ String
The country registered for the Merchant Center feed that contains the product.
-
#product_group_id ⇒ Fixnum
DS product group ID.
-
#product_id ⇒ String
The product ID (SKU).
-
#product_language ⇒ String
The language registered for the Merchant Center feed that contains the product.
-
#quantity_millis ⇒ Fixnum
The quantity of this conversion, in millis.
-
#revenue_micros ⇒ String
The revenue amount of this
TRANSACTIONconversion, in micros (value multiplied by 1000000, no decimal). -
#segmentation_id ⇒ Fixnum
The numeric segmentation identifier (for example, DoubleClick Search Floodlight activity ID).
-
#segmentation_name ⇒ String
The friendly segmentation identifier (for example, DoubleClick Search Floodlight activity name).
-
#segmentation_type ⇒ String
The segmentation type of this conversion (for example,
FLOODLIGHT). -
#state ⇒ String
The state of the conversion, that is, either
ACTIVEorREMOVED. -
#store_id ⇒ String
The ID of the local store for which the product was advertised.
-
#type ⇒ String
The type of the conversion, that is, either
ACTIONorTRANSACTION.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Conversion
constructor
A new instance of Conversion.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Conversion
Returns a new instance of Conversion.
289 290 291 |
# File 'lib/google/apis/doubleclicksearch_v2/classes.rb', line 289 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ad_group_id ⇒ Fixnum
DS ad group ID.
Corresponds to the JSON property adGroupId
91 92 93 |
# File 'lib/google/apis/doubleclicksearch_v2/classes.rb', line 91 def ad_group_id @ad_group_id end |
#ad_id ⇒ Fixnum
DS ad ID.
Corresponds to the JSON property adId
96 97 98 |
# File 'lib/google/apis/doubleclicksearch_v2/classes.rb', line 96 def ad_id @ad_id end |
#ad_user_data_consent ⇒ String
Represents consent for core platform services (CPS) preferences in settings.
No default value. Acceptable values are: GRANTED: The desired consent status
is to grant. Read the CPS preferences from GTE settings. DENIED: The desired
consent status is to deny; CPS list is empty.
Corresponds to the JSON property adUserDataConsent
104 105 106 |
# File 'lib/google/apis/doubleclicksearch_v2/classes.rb', line 104 def @ad_user_data_consent end |
#advertiser_id ⇒ Fixnum
DS advertiser ID.
Corresponds to the JSON property advertiserId
109 110 111 |
# File 'lib/google/apis/doubleclicksearch_v2/classes.rb', line 109 def advertiser_id @advertiser_id end |
#agency_id ⇒ Fixnum
DS agency ID.
Corresponds to the JSON property agencyId
114 115 116 |
# File 'lib/google/apis/doubleclicksearch_v2/classes.rb', line 114 def agency_id @agency_id end |
#attribution_model ⇒ String
Available to advertisers only after contacting DoubleClick Search customer
support.
Corresponds to the JSON property attributionModel
120 121 122 |
# File 'lib/google/apis/doubleclicksearch_v2/classes.rb', line 120 def attribution_model @attribution_model end |
#campaign_id ⇒ Fixnum
DS campaign ID.
Corresponds to the JSON property campaignId
125 126 127 |
# File 'lib/google/apis/doubleclicksearch_v2/classes.rb', line 125 def campaign_id @campaign_id end |
#channel ⇒ String
Sales channel for the product. Acceptable values are: - "local": a physical
store - "online": an online store
Corresponds to the JSON property channel
131 132 133 |
# File 'lib/google/apis/doubleclicksearch_v2/classes.rb', line 131 def channel @channel end |
#click_id ⇒ String
DS click ID for the conversion.
Corresponds to the JSON property clickId
136 137 138 |
# File 'lib/google/apis/doubleclicksearch_v2/classes.rb', line 136 def click_id @click_id end |
#conversion_id ⇒ String
For offline conversions, advertisers provide this ID. Advertisers can specify
any ID that is meaningful to them. Each conversion in a request must specify a
unique ID, and the combination of ID and timestamp must be unique amongst all
conversions within the advertiser. For online conversions, DS copies the
dsConversionId or floodlightOrderId into this property depending on the
advertiser's Floodlight instructions.
Corresponds to the JSON property conversionId
146 147 148 |
# File 'lib/google/apis/doubleclicksearch_v2/classes.rb', line 146 def conversion_id @conversion_id end |
#conversion_modified_timestamp ⇒ Fixnum
The time at which the conversion was last modified, in epoch millis UTC.
Corresponds to the JSON property conversionModifiedTimestamp
151 152 153 |
# File 'lib/google/apis/doubleclicksearch_v2/classes.rb', line 151 def @conversion_modified_timestamp end |
#conversion_timestamp ⇒ String
The time at which the conversion took place, in epoch millis UTC.
Corresponds to the JSON property conversionTimestamp
156 157 158 |
# File 'lib/google/apis/doubleclicksearch_v2/classes.rb', line 156 def @conversion_timestamp end |
#count_millis ⇒ Fixnum
Available to advertisers only after contacting DoubleClick Search customer
support.
Corresponds to the JSON property countMillis
162 163 164 |
# File 'lib/google/apis/doubleclicksearch_v2/classes.rb', line 162 def count_millis @count_millis end |
#criterion_id ⇒ Fixnum
DS criterion (keyword) ID.
Corresponds to the JSON property criterionId
167 168 169 |
# File 'lib/google/apis/doubleclicksearch_v2/classes.rb', line 167 def criterion_id @criterion_id end |
#currency_code ⇒ String
The currency code for the conversion's revenue. Should be in ISO 4217
alphabetic (3-char) format.
Corresponds to the JSON property currencyCode
173 174 175 |
# File 'lib/google/apis/doubleclicksearch_v2/classes.rb', line 173 def currency_code @currency_code end |
#custom_dimension ⇒ Array<Google::Apis::DoubleclicksearchV2::CustomDimension>
Custom dimensions for the conversion, which can be used to filter data in a
report.
Corresponds to the JSON property customDimension
179 180 181 |
# File 'lib/google/apis/doubleclicksearch_v2/classes.rb', line 179 def custom_dimension @custom_dimension end |
#custom_metric ⇒ Array<Google::Apis::DoubleclicksearchV2::CustomMetric>
Custom metrics for the conversion.
Corresponds to the JSON property customMetric
184 185 186 |
# File 'lib/google/apis/doubleclicksearch_v2/classes.rb', line 184 def custom_metric @custom_metric end |
#customer_id ⇒ String
Customer ID of a client account in the new Search Ads 360 experience.
Corresponds to the JSON property customerId
189 190 191 |
# File 'lib/google/apis/doubleclicksearch_v2/classes.rb', line 189 def customer_id @customer_id end |
#device_type ⇒ String
The type of device on which the conversion occurred.
Corresponds to the JSON property deviceType
194 195 196 |
# File 'lib/google/apis/doubleclicksearch_v2/classes.rb', line 194 def device_type @device_type end |
#ds_conversion_id ⇒ Fixnum
ID that DoubleClick Search generates for each conversion.
Corresponds to the JSON property dsConversionId
199 200 201 |
# File 'lib/google/apis/doubleclicksearch_v2/classes.rb', line 199 def ds_conversion_id @ds_conversion_id end |
#engine_account_id ⇒ Fixnum
DS engine account ID.
Corresponds to the JSON property engineAccountId
204 205 206 |
# File 'lib/google/apis/doubleclicksearch_v2/classes.rb', line 204 def engine_account_id @engine_account_id end |
#floodlight_order_id ⇒ String
The Floodlight order ID provided by the advertiser for the conversion.
Corresponds to the JSON property floodlightOrderId
209 210 211 |
# File 'lib/google/apis/doubleclicksearch_v2/classes.rb', line 209 def floodlight_order_id @floodlight_order_id end |
#inventory_account_id ⇒ Fixnum
ID that DS generates and uses to uniquely identify the inventory account that
contains the product.
Corresponds to the JSON property inventoryAccountId
215 216 217 |
# File 'lib/google/apis/doubleclicksearch_v2/classes.rb', line 215 def inventory_account_id @inventory_account_id end |
#product_country ⇒ String
The country registered for the Merchant Center feed that contains the product.
Use an ISO 3166 code to specify a country.
Corresponds to the JSON property productCountry
221 222 223 |
# File 'lib/google/apis/doubleclicksearch_v2/classes.rb', line 221 def product_country @product_country end |
#product_group_id ⇒ Fixnum
DS product group ID.
Corresponds to the JSON property productGroupId
226 227 228 |
# File 'lib/google/apis/doubleclicksearch_v2/classes.rb', line 226 def product_group_id @product_group_id end |
#product_id ⇒ String
The product ID (SKU).
Corresponds to the JSON property productId
231 232 233 |
# File 'lib/google/apis/doubleclicksearch_v2/classes.rb', line 231 def product_id @product_id end |
#product_language ⇒ String
The language registered for the Merchant Center feed that contains the product.
Use an ISO 639 code to specify a language.
Corresponds to the JSON property productLanguage
237 238 239 |
# File 'lib/google/apis/doubleclicksearch_v2/classes.rb', line 237 def product_language @product_language end |
#quantity_millis ⇒ Fixnum
The quantity of this conversion, in millis.
Corresponds to the JSON property quantityMillis
242 243 244 |
# File 'lib/google/apis/doubleclicksearch_v2/classes.rb', line 242 def quantity_millis @quantity_millis end |
#revenue_micros ⇒ String
The revenue amount of this TRANSACTION conversion, in micros (value
multiplied by 1000000, no decimal). For example, to specify a revenue value of
"10" enter "10000000" (10 million) in your request.
Corresponds to the JSON property revenueMicros
249 250 251 |
# File 'lib/google/apis/doubleclicksearch_v2/classes.rb', line 249 def revenue_micros @revenue_micros end |
#segmentation_id ⇒ Fixnum
The numeric segmentation identifier (for example, DoubleClick Search
Floodlight activity ID).
Corresponds to the JSON property segmentationId
255 256 257 |
# File 'lib/google/apis/doubleclicksearch_v2/classes.rb', line 255 def segmentation_id @segmentation_id end |
#segmentation_name ⇒ String
The friendly segmentation identifier (for example, DoubleClick Search
Floodlight activity name).
Corresponds to the JSON property segmentationName
261 262 263 |
# File 'lib/google/apis/doubleclicksearch_v2/classes.rb', line 261 def segmentation_name @segmentation_name end |
#segmentation_type ⇒ String
The segmentation type of this conversion (for example, FLOODLIGHT).
Corresponds to the JSON property segmentationType
266 267 268 |
# File 'lib/google/apis/doubleclicksearch_v2/classes.rb', line 266 def segmentation_type @segmentation_type end |
#state ⇒ String
The state of the conversion, that is, either ACTIVE or REMOVED. Note:
state DELETED is deprecated.
Corresponds to the JSON property state
272 273 274 |
# File 'lib/google/apis/doubleclicksearch_v2/classes.rb', line 272 def state @state end |
#store_id ⇒ String
The ID of the local store for which the product was advertised. Applicable
only when the channel is "local".
Corresponds to the JSON property storeId
278 279 280 |
# File 'lib/google/apis/doubleclicksearch_v2/classes.rb', line 278 def store_id @store_id end |
#type ⇒ String
The type of the conversion, that is, either ACTION or TRANSACTION. An
ACTION conversion is an action by the user that has no monetarily
quantifiable value, while a TRANSACTION conversion is an action that does
have a monetarily quantifiable value. Examples are email list signups (ACTION
) versus ecommerce purchases (TRANSACTION).
Corresponds to the JSON property type
287 288 289 |
# File 'lib/google/apis/doubleclicksearch_v2/classes.rb', line 287 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 |
# File 'lib/google/apis/doubleclicksearch_v2/classes.rb', line 294 def update!(**args) @ad_group_id = args[:ad_group_id] if args.key?(:ad_group_id) @ad_id = args[:ad_id] if args.key?(:ad_id) @ad_user_data_consent = args[:ad_user_data_consent] if args.key?(:ad_user_data_consent) @advertiser_id = args[:advertiser_id] if args.key?(:advertiser_id) @agency_id = args[:agency_id] if args.key?(:agency_id) @attribution_model = args[:attribution_model] if args.key?(:attribution_model) @campaign_id = args[:campaign_id] if args.key?(:campaign_id) @channel = args[:channel] if args.key?(:channel) @click_id = args[:click_id] if args.key?(:click_id) @conversion_id = args[:conversion_id] if args.key?(:conversion_id) @conversion_modified_timestamp = args[:conversion_modified_timestamp] if args.key?(:conversion_modified_timestamp) @conversion_timestamp = args[:conversion_timestamp] if args.key?(:conversion_timestamp) @count_millis = args[:count_millis] if args.key?(:count_millis) @criterion_id = args[:criterion_id] if args.key?(:criterion_id) @currency_code = args[:currency_code] if args.key?(:currency_code) @custom_dimension = args[:custom_dimension] if args.key?(:custom_dimension) @custom_metric = args[:custom_metric] if args.key?(:custom_metric) @customer_id = args[:customer_id] if args.key?(:customer_id) @device_type = args[:device_type] if args.key?(:device_type) @ds_conversion_id = args[:ds_conversion_id] if args.key?(:ds_conversion_id) @engine_account_id = args[:engine_account_id] if args.key?(:engine_account_id) @floodlight_order_id = args[:floodlight_order_id] if args.key?(:floodlight_order_id) @inventory_account_id = args[:inventory_account_id] if args.key?(:inventory_account_id) @product_country = args[:product_country] if args.key?(:product_country) @product_group_id = args[:product_group_id] if args.key?(:product_group_id) @product_id = args[:product_id] if args.key?(:product_id) @product_language = args[:product_language] if args.key?(:product_language) @quantity_millis = args[:quantity_millis] if args.key?(:quantity_millis) @revenue_micros = args[:revenue_micros] if args.key?(:revenue_micros) @segmentation_id = args[:segmentation_id] if args.key?(:segmentation_id) @segmentation_name = args[:segmentation_name] if args.key?(:segmentation_name) @segmentation_type = args[:segmentation_type] if args.key?(:segmentation_type) @state = args[:state] if args.key?(:state) @store_id = args[:store_id] if args.key?(:store_id) @type = args[:type] if args.key?(:type) end |