Class: Google::Apis::DoubleclicksearchV2::ReportRequest::ReportScope
- Inherits:
-
Object
- Object
- Google::Apis::DoubleclicksearchV2::ReportRequest::ReportScope
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/doubleclicksearch_v2/classes.rb,
lib/google/apis/doubleclicksearch_v2/representations.rb,
lib/google/apis/doubleclicksearch_v2/representations.rb
Overview
The reportScope is a set of IDs that are used to determine which subset of entities will be returned in the report. The full lineage of IDs from the lowest scoped level desired up through agency is required.
Instance Attribute Summary collapse
-
#ad_group_id ⇒ Fixnum
DS ad group ID.
-
#ad_id ⇒ Fixnum
DS ad ID.
-
#advertiser_id ⇒ Fixnum
DS advertiser ID.
-
#agency_id ⇒ Fixnum
DS agency ID.
-
#campaign_id ⇒ Fixnum
DS campaign ID.
-
#engine_account_id ⇒ Fixnum
DS engine account ID.
-
#keyword_id ⇒ Fixnum
DS keyword ID.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReportScope
constructor
A new instance of ReportScope.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReportScope
Returns a new instance of ReportScope.
844 845 846 |
# File 'lib/google/apis/doubleclicksearch_v2/classes.rb', line 844 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ad_group_id ⇒ Fixnum
DS ad group ID.
Corresponds to the JSON property adGroupId
812 813 814 |
# File 'lib/google/apis/doubleclicksearch_v2/classes.rb', line 812 def ad_group_id @ad_group_id end |
#ad_id ⇒ Fixnum
DS ad ID.
Corresponds to the JSON property adId
817 818 819 |
# File 'lib/google/apis/doubleclicksearch_v2/classes.rb', line 817 def ad_id @ad_id end |
#advertiser_id ⇒ Fixnum
DS advertiser ID.
Corresponds to the JSON property advertiserId
822 823 824 |
# File 'lib/google/apis/doubleclicksearch_v2/classes.rb', line 822 def advertiser_id @advertiser_id end |
#agency_id ⇒ Fixnum
DS agency ID.
Corresponds to the JSON property agencyId
827 828 829 |
# File 'lib/google/apis/doubleclicksearch_v2/classes.rb', line 827 def agency_id @agency_id end |
#campaign_id ⇒ Fixnum
DS campaign ID.
Corresponds to the JSON property campaignId
832 833 834 |
# File 'lib/google/apis/doubleclicksearch_v2/classes.rb', line 832 def campaign_id @campaign_id end |
#engine_account_id ⇒ Fixnum
DS engine account ID.
Corresponds to the JSON property engineAccountId
837 838 839 |
# File 'lib/google/apis/doubleclicksearch_v2/classes.rb', line 837 def engine_account_id @engine_account_id end |
#keyword_id ⇒ Fixnum
DS keyword ID.
Corresponds to the JSON property keywordId
842 843 844 |
# File 'lib/google/apis/doubleclicksearch_v2/classes.rb', line 842 def keyword_id @keyword_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
849 850 851 852 853 854 855 856 857 |
# File 'lib/google/apis/doubleclicksearch_v2/classes.rb', line 849 def update!(**args) @ad_group_id = args[:ad_group_id] if args.key?(:ad_group_id) @ad_id = args[:ad_id] if args.key?(:ad_id) @advertiser_id = args[:advertiser_id] if args.key?(:advertiser_id) @agency_id = args[:agency_id] if args.key?(:agency_id) @campaign_id = args[:campaign_id] if args.key?(:campaign_id) @engine_account_id = args[:engine_account_id] if args.key?(:engine_account_id) @keyword_id = args[:keyword_id] if args.key?(:keyword_id) end |