Class: Google::Apis::DoubleclicksearchV2::SavedColumnList
- Inherits:
-
Object
- Object
- Google::Apis::DoubleclicksearchV2::SavedColumnList
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/doubleclicksearch_v2/classes.rb,
lib/google/apis/doubleclicksearch_v2/representations.rb,
lib/google/apis/doubleclicksearch_v2/representations.rb
Overview
A list of saved columns. Advertisers create saved columns to report on Floodlight activities, Google Analytics goals, or custom KPIs. To request reports with saved columns, you'll need the saved column names that are available from this list.
Instance Attribute Summary collapse
-
#items ⇒ Array<Google::Apis::DoubleclicksearchV2::SavedColumn>
The saved columns being requested.
-
#kind ⇒ String
Identifies this as a SavedColumnList resource.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SavedColumnList
constructor
A new instance of SavedColumnList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SavedColumnList
Returns a new instance of SavedColumnList.
951 952 953 |
# File 'lib/google/apis/doubleclicksearch_v2/classes.rb', line 951 def initialize(**args) update!(**args) end |
Instance Attribute Details
#items ⇒ Array<Google::Apis::DoubleclicksearchV2::SavedColumn>
The saved columns being requested.
Corresponds to the JSON property items
943 944 945 |
# File 'lib/google/apis/doubleclicksearch_v2/classes.rb', line 943 def items @items end |
#kind ⇒ String
Identifies this as a SavedColumnList resource. Value: the fixed string
doubleclicksearch#savedColumnList.
Corresponds to the JSON property kind
949 950 951 |
# File 'lib/google/apis/doubleclicksearch_v2/classes.rb', line 949 def kind @kind end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
956 957 958 959 |
# File 'lib/google/apis/doubleclicksearch_v2/classes.rb', line 956 def update!(**args) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) end |